pecos.misc.stabilizer\_funcs
============================

.. automodule:: pecos.misc.stabilizer_funcs







   .. rubric:: Functions

   .. autosummary::

      circ2set
      find_stab
      is_not_stabilizer
      op_commutes
      remove_stab
